#ifndef _decrypt_file_h_
#define _decrypt_file_h_

#include <stdio.h>
#include "mem.h"

void decrypt_file (FILE* input, FILE* output, int algo);

#endif

